#
# spec file for package LibVNCServer
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           LibVNCServer
Version:        0.9.10
Release:        lp150.3.10.1
Summary:        VNC Development Library
License:        GPL-2.0+
Group:          Development/Libraries/X11
Url:            https://github.com/LibVNC/libvncserver
# Archive is renamed by github
#Source0:        https://github.com/LibVNC/libvncserver/archive/%{name}-%{version}.tar.gz
Source0:        libvncserver-%{name}-%{version}.tar.gz
Source1:        baselibs.conf
#PATCH-FIX-OPENSUSE: multilib support
Patch1:         libvncserver-0.9.1-multilib.patch
#PATCH-FIX-OPENSUSE: redefine keysyms only if needed
Patch7:         redef-keysym.patch
#PATCH_FIX-OPENSUSE: Use system fast byteswap routines.
Patch11:        libvncserver-byteswap.patch
Patch12:        libvncserver-%{version}-ossl.patch
#PATCH-FIX-UPSTREAM: use namespaced rfbMax macro (avoids conflicts with stl_algobase.h), picked from upstream
Patch13:        libvncserver-0.9.10-use-namespaced-rfbMax-macro.patch
Patch14:        LibVNCServer-CVE-2018-7225.patch
Patch15:        LibVNCServer-CVE-2018-15126.patch
Patch16:        LibVNCServer-CVE-2018-6307.patch
Patch17:        LibVNCServer-CVE-2018-20020.patch
Patch18:        LibVNCServer-CVE-2018-15127.patch
Patch19:        LibVNCServer-CVE-2018-20019.patch
Patch20:        LibVNCServer-CVE-2018-20023.patch
Patch21:        LibVNCServer-CVE-2018-20022.patch
Patch22:        LibVNCServer-CVE-2018-20024.patch
Patch23:        LibVNCServer-CVE-2018-20021.patch
Patch24:        LibVNCServer-CVE-2018-20749.patch
Patch25:        LibVNCServer-CVE-2018-20750.patch
Patch26:        LibVNCServer-CVE-2018-20748.patch
BuildRequires:  libavahi-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libgnutls-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  lzo-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  slang-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
VNC is a set of programs using the RFB (Remote Frame Buffer) protocol.
They are designed to "export" a frame buffer via the network. It is
already in wide use for administration, but it is not that easy to
program a server yourself. This has been changed by LibVNCServer.

X.org already has a virtual Xvnc server which you can start as an own
screen (e.g. :1) and connect to with a VNC client (e.g. vncviewer from
tightvnc). The x11vnc binary (that allows you to export the window of a
real running X11 server) has been split off into its own package on
2007-07-16.

%package -n libvncclient0
Summary:        Library implementing a VNC client
Group:          System/Libraries
Obsoletes:      linuxvnc < %{version}
Conflicts:      LibVNCServer < %version

%description -n libvncclient0
LibVNCServer/LibVNCClient are cross-platform C libraries that allow
implementing VNC server or client functionality in your program.

%package -n libvncserver0
Summary:        Library implementing a VNC server
Group:          System/Libraries

%description -n libvncserver0
LibVNCServer/LibVNCClient are cross-platform C libraries that allow
implementing VNC server or client functionality in your program.

%package devel
Requires:       gnutls-devel
Requires:       libvncclient0 = %version
Requires:       libvncserver0 = %version
Requires:       zlib-devel
Summary:        VNC Development Library
Group:          Development/Libraries/X11

%description devel
VNC is a set of programs using the RFB (Remote Frame Buffer) protocol.
They are designed to "export" a frame buffer via the network. It is
already in wide use for administration, but it is not that easy to
program a server yourself. This has been changed by LibVNCServer.

X.org already has a virtual Xvnc server which you can start as an own
screen (e.g. :1) and connect to with a VNC client (e.g. vncviewer from
tightvnc).

The LibVNCServer-devel package contains the static libraries and header
files for LibVNCServer.

%prep
%setup -q -n libvncserver-%{name}-%{version}
%patch1 -p1 -b .multilib
#%patch2 -p1 -b .system_minilzo
%patch7 -p1
# aclocal; autoheader; automake --add-missing --copy; autoconf
# ./configure --enable-maintainer-mode
# sh ./autogen.sh
%patch11
%patch12
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
# fix encoding
for file in AUTHORS ChangeLog ; do
mv ${file} ${file}.OLD && \
iconv -f ISO_8859-1 -t UTF8 ${file}.OLD > ${file} && \
touch --reference ${file}.OLD $file 
done

#nuke bundled minilzo
#rm -f common/lzodefs.h common/lzoconf.h commmon/minilzo.h common/minilzo.c

# needed by patch 2 (and to nuke rpath's)
#autoreconf

%build
CFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE -D_REENTRANT" \
NOCONFIGURE=1 ./autogen.sh

# Plase note that tightvn cause a problem; need to be fix
%configure --disable-static --with-pic --enable-shared --with-gnu-ld --without-tightvnc-filetransfer

make %{?_smp_mflags}

%{__install} -d -m0755 RPM_BUILD_ROOT%{_datadir}/x11vnc/classes

%check 
make check

%install
%makeinstall
%{__rm} -f %{buildroot}%{_libdir}/*.la
%{__rm} -f %{buildroot}%{_libdir}/*.a

%post   -n libvncclient0 -p /sbin/ldconfig
%postun -n libvncclient0 -p /sbin/ldconfig
%post   -n libvncserver0 -p /sbin/ldconfig
%postun -n libvncserver0 -p /sbin/ldconfig

%files -n libvncserver0
%defattr(-,root,root)
%doc COPYING README
%_libdir/libvncserver.so.0*

%files -n libvncclient0
%defattr(-,root,root)
%doc COPYING README
%_libdir/libvncclient.so.0*

%files devel
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README TODO
%{_bindir}/libvncserver-config
%{_includedir}/rfb/*
%dir /usr/include/rfb
%{_libdir}/libvncclient.so
%{_libdir}/libvncserver.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Wed Feb 20 2019 Felix Zhang <fezhang@suse.com>
- Add BuildRequire libgnutls-devel: Remmina needs it for VNC
  connections (boo#1123805)
* Tue Feb  5 2019 Petr Gajdos <pgajdos@suse.com>
- security update
  * CVE-2018-20749 [bsc#1123828]
    + LibVNCServer-CVE-2018-20749.patch
  * CVE-2018-20750 [bsc#1123832]
    + LibVNCServer-CVE-2018-20750.patch
  * CVE-2018-20748 [bsc#1123823]
    + LibVNCServer-CVE-2018-20748.patch
* Thu Jan  3 2019 Petr Gajdos <pgajdos@suse.com>
- security update
  * CVE-2018-15126 [bsc#1120114]
    + LibVNCServer-CVE-2018-15126.patch
  * CVE-2018-6307 [bsc#1120115]
    + LibVNCServer-CVE-2018-6307.patch
  * CVE-2018-20020 [bsc#1120116]
    + LibVNCServer-CVE-2018-20020.patch
  * CVE-2018-15127 [bsc#1120117]
    + LibVNCServer-CVE-2018-15127.patch
  * CVE-2018-20019 [bsc#1120118]
    + LibVNCServer-CVE-2018-20019.patch
  * CVE-2018-20023 [bsc#1120119]
    + LibVNCServer-CVE-2018-20023.patch
  * CVE-2018-20022 [bsc#1120120]
    + LibVNCServer-CVE-2018-20022.patch
  * CVE-2018-20024 [bsc#1120121]
    + LibVNCServer-CVE-2018-20024.patch
  * CVE-2018-20021 [bsc#1120122]
    + LibVNCServer-CVE-2018-20021.patch
* Tue Mar 20 2018 pgajdos@suse.com
- security update
  * CVE-2018-7225 [bsc#1081493]
    + LibVNCServer-CVE-2018-7225.patch
* Tue May 24 2016 antoine.belvire@laposte.net
- Fix build errors of applications using stl_algobase.h and
  libvncserver's rfbproto.h, e.g. krfb (issue #102)
  * Add libvncserver-0.9.10-use-namespaced-rfbMax-macro.patch
* Sun Feb  8 2015 crrodriguez@opensuse.org
- Remove xorg-x11-devel from buildRequires, X libraries
  are not directly used/linked
* Sun Feb  8 2015 crrodriguez@opensuse.org
- libvncserver-0.9.10-ossl.patch: Update, do not
  RAND_load_file("/dev/urandom", 1024) if the the PRNG is already
  seeded. (It always is on linux)
* Sat Dec 13 2014 p.drouand@gmail.com
- Update to version 0.9.10
  + Moved the whole project from sourceforge to https://libvnc.github.io/.
  + Cleaned out the autotools build system which now uses autoreconf.
  + Updated noVNC HTML5 client to latest version.
  + Split out x11vnc sources into separate repository at
    https://github.com/LibVNC/x11vnc
  + Split out vncterm sources into separate repository at
    https://github.com/LibVNC/vncterm
  + Split out VisualNaCro sources into separate repository at
    https://github.com/LibVNC/VisualNaCro
  + Merged Debian patches.
  + Fixed some security-related buffer overflow cases.
  + Added compatibility headers to make LibVNCServer/LibVNCClient
    build on native Windows 8.
  + Update LZO to version 2.07, fixing CVE-2014-4607.
  + Merged patches from KDE/krfb.
  + Can now do IPv6 without IPv4.
  + Fixed a use-after-free issue in scale.c.
- Update Url and download source to new project home
- Remove LibVNCServer-0.9.9-no_x11vnc.patch; upstream splited it
  out of main tarball
- Rebase libvncserver-ossl.patch to upstream changes
  > libvncserver-0.9.10-ossl.patch
- Remove linuxvnc subpackage; like x11vnc, it has been splited out
  but is depreciated and unmaintained.
* Fri Oct  3 2014 olaf@aepfle.de
- Obsolete old LibVNCServer.rpm in libvncclient0 package. The old
  version included binaries, devel and runtime libs. But nothing
  removes the old package, which leads to file conflicts during
  upgrade if linuxvnc.rpm is not on the install media (bnc#893343)
* Tue Jul  1 2014 coolo@suse.com
- remove old .bz2 file
* Mon Mar 18 2013 mmeister@suse.com
- Add Url to Source section in spec file
* Sat Jan 12 2013 jengelh@inai.de
- Follow shared library packaging guidelines
- Avoid self-obsolete tag
- Put libvncserver-config into -devel where it should belong
- Provide pkgconfig() RPM symbols
* Tue Jan  1 2013 crrodriguez@opensuse.org
- Switch SSL backend to openssl, we all agree that OpenSSL
  has it faults, but it is heavily optimized in all platforms
  not only x86 and performance matters in interactive,latency
  sensitive tasks like VNC.
- libvncserver-ossl.patch Ensures openssl use less memory
  and avoid abi breaks on openSSL updates.
* Sun Dec 30 2012 crrodriguez@opensuse.org
- libvncserver-byteswap.patch : USe OS byteswapping macros
  which are optimized for the target arch.
- BuildRequire libpng-Devel
* Tue Oct 16 2012 mvyskocil@suse.com
- delete not used LibVNCServer-0.9.9-system_minilzo.patch
- document patches
- rename redef-keysym to redef-keysym.patch
* Wed Sep 26 2012 p.drouand@gmail.com
- Update to 0.9.9 version:
  - Overall changes:
  * Added noVNC HTML5 VNC viewer (http://kanaka.github.com/noVNC/) connect possibility
    to our http server. Pure JavaScript, no Java plugin required anymore! (But a
    recent browser...)
  * Added a GTK+ VNC viewer example.
  - LibVNCServer/LibVNCClient:
  * Added support to build for Google Android.
  * Complete IPv6 support in both LibVNCServer and LibVNCClient.
  - LibVNCServer:
  * Split two event-loop related functions out of the rfbProcessEvents() mechanism.
    This is required to be able to do proper event loop integration with Qt. Idea was
    taken from Vino's libvncserver fork.
  * Added TightPNG (http://wiki.qemu.org/VNC_Tight_PNG) encoding support. Like the
    original Tight encoding, this still uses JPEG, but ZLIB encoded rects are encoded
    with PNG here.
  * Added suport for serving VNC sessions through WebSockets
    (http://en.wikipedia.org/wiki/WebSocket), a web technology providing for multiplexing
    bi-directional, full-duplex communications channels over a single TCP connection.
  * Support connections from the Mac OS X built-in VNC client to LibVNCServer
    instances running with no password.
  * Replaced the Tight encoder with a TurboVNC one which is tremendously faster in most
    cases, especially with high-color video or 3D workloads.
    (http://www.virtualgl.org/pmwiki/uploads/About/tighttoturbo.pdf)
  - LibVNCClient:
  * Added support to only listen for reverse connections on a specific IP address.
  * Support for using OpenSSL instead of GnuTLS. This could come in handy on embedded
    devices where only this TLS implementation is available.
  * Added support to connect to UltraVNC Single Click servers.
- remove upstreamed LibVNCServer-LINUX.diff
- remove upstreamed LibVNCServer-0.9.8_git201104301110-overflow.patch
- remove upstreamed LibVNCServer-system-lzo.patch
- rename and refresh dont-build-x11vnc to LibVNCServer-0.9.9-no_x11vnc.patch
- add, but not enable LibVNCServer-0.9.9-system_minilzo.patch
- add libvncserver-0.9.1-multilib.patch
* Mon Aug 27 2012 idonmez@suse.com
- Devel package needs a dependency on gnutls-devel
* Sat Aug 18 2012 gber@opensuse.org
- enable support for gnutls
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Fri May  6 2011 crrodriguez@opensuse.org
- Update to version 0.9.8 latest.
  * Changes too long to list here, see NEWS
- Use system lzo library
* Fri Oct  8 2010 coolo@novell.com
- add baselibs.conf to build 32bit libs for DirectFB-32bit to use
* Tue Apr 21 2009 garloff@suse.de
- Update to LibVNCserver-0.9.7:
  * add (server-side) ZYWRLE support
  * fixes (update after resizing, endianess, width != scanline)
  * improve timeouts, port fallback, and connection time of the SSL
    Java viewers
* Fri Mar  6 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Mon Oct 27 2008 garloff@suse.de
- fix-warn.diff: Avoid pointer > 0 comparison (bnc 435610)
* Mon Feb 25 2008 crrodriguez@suse.de
- fix library-without-ldconfig-post* errors
- devel package requires zlib-devel
* Thu Oct 11 2007 sbrabec@suse.cz
- Use binding specific avahi package.
* Mon Jul 16 2007 garloff@suse.de
- Split LibVNCServer into itself, -devel and x11vnc.
- Update to LibVNCserver-0.9.1.
- Drop patches that have been integrated upstream.
* Wed Apr 11 2007 stbinner@suse.de
- fix misplaced guards in rfb.h
* Thu Mar 15 2007 ccoffing@novell.com
- Fix incorrect usage of condition variables, which was causing
  a crash during heavy updates. (#246100)
* Fri Jul 28 2006 garloff@suse.de
- Update to version 0.8.2:
  * Support for VNC protocol version 3.8.
  * Many UltraVNC encodings and features added: FileTransfer,
    SetSingleWindow, ServerInput, TextChat, UltraZip, etc.
  * Support for PalmVNC and UltraVNC style 1/n server-side scaling.
  * Improved Statistics reporting.
  * KeyboardLedState encoding.
  * LibVNCClient and x11vnc enhancements.
  * Many bugs and leaks fixed.
  * CVE-2006-2450 fix is already included, drop patch.
- Use -allinput in x11vnc_ssh script.
* Mon Jun 19 2006 garloff@suse.de
- Update to version 0.8.
- Enable -fstack-protector for auth relevant files.
- Fix some compiler warnings.
- Disallow NoneAuth if password is set (#184418, CVE-2006-2450).
* Fri Feb 24 2006 garloff@suse.de
- Optimize event loop in LibVNCserver (from intel for Xen).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec 30 2005 garloff@suse.de
- Don't enable -threads by default; it's performance is nice, but
  the stability is not that great.
- Include x11vnc_ssh in distribution.
* Thu Dec 22 2005 garloff@suse.de
- Workaround for -thread mode: Wait for a client being fully
  authenticated before sending data.
* Wed Dec 21 2005 garloff@suse.de
- Update to LibVNCServer-0.7.99
- Fix compiler detected bugs (uninitialized var, buffer overflow).
- Package documentation.
* Tue Dec 20 2005 ro@suse.de
- do not try to detect LINUX by presence of /dev/vcsa1
* Sun Aug 21 2005 garloff@suse.de
- Initial creation of package LibVNCServer-0.7.1.
